package j3d.utils;

/*
      @(#)MaterialPresetEditor.java 1.2 01/08/01 11:02:20

***************************************************************
"Copyright (c) 2001 Sun Microsystems, Inc. All Rights Reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

-Redistributions of source code must retain the above copyright notice, this
list of conditions and the following disclaimer.

-Redistribution in binary form must reproduce the above copyright notice, this
list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

Neither the name of Sun Microsystems, Inc. or the names of contributors may be
used to endorse or promote products derived from this software without
specific prior written permission.

This software is provided "AS IS," without a warranty of any kind. ALL
EXPRESS OR IMPLIED CONDITIONS, REPRESENTATIONS AND WARRANTIES, INCLUDING ANY
IMPLIED WARRANTY OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR
NON-INFRINGEMENT, ARE HEREBY EXCLUDED. SUN AND ITS LICENSORS SHALL NOT BE
LIABLE FOR ANY DAMAGES SUFFERED BY LICENSEE AS A RESULT OF USING, MODIFYING
OR DISTRIBUTING THE SOFTWARE OR ITS DERIVATIVES. IN NO EVENT WILL SUN OR ITS
LICENSORS BE LIABLE FOR ANY LOST REVENUE, PROFIT OR DATA, OR FOR DIRECT,
INDIRECT, SPECIAL, CONSEQUENTIAL, INCIDENTAL OR PUNITIVE DAMAGES, HOWEVER
CAUSED AND REGARDLESS OF THE THEORY OF LIABILITY, ARISING OUT OF THE USE OF
OR INABILITY TO USE SOFTWARE, EVEN IF SUN HAS BEEN ADVISED OF THE
POSSIBILITY OF SUCH DAMAGES.

You acknowledge that Software is not designed,licensed or intended for use in
the design, construction, operation or maintenance of any nuclear facility."

****************************************************************************
*/

import gui.layouts.LeftAlignComponent;
import gui.run.IntChooser;

import javax.media.j3d.Material;
import javax.swing.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;


public class MaterialPresetEditor extends MaterialEditor implements
        ActionListener {

    String[] materialNames;
    Material[] materialPresets;
    IntChooser presetChooser;

    public MaterialPresetEditor(Material init, String[] presetNames,
                                Material[] presets) {

        super(init);
        if ((presetNames.length != presets.length)) {
            throw new IllegalArgumentException("Preset name and value arrays must have the same length");
        }
        materialNames = presetNames;
        materialPresets = presets;

        JPanel presetPanel = new JPanel();

        presetChooser = new IntChooser("Preset:",
                materialNames);
        presetPanel.add(presetChooser);

        JButton presetCopyButton = new JButton("Copy preset");
        presetCopyButton.addActionListener(this);
        presetPanel.add(presetCopyButton);

        add(new LeftAlignComponent(presetPanel));
    }

    // copy when button is pressed
    public void actionPerformed(ActionEvent e) {
        Material copyMaterial = materialPresets[presetChooser.getValue()];

        lightingEnable = copyMaterial.getLightingEnable();
        copyMaterial.getAmbientColor(ambientColor);
        copyMaterial.getDiffuseColor(diffuseColor);
        copyMaterial.getEmissiveColor(emissiveColor);
        copyMaterial.getSpecularColor(specularColor);
        shininess = copyMaterial.getShininess();

        // update the GUI
        lightingEnableCheckBox.setSelected(lightingEnable);
        material.setLightingEnable(lightingEnable);
        ambientEditor.setValue(ambientColor);
        diffuseEditor.setValue(diffuseColor);
        emissiveEditor.setValue(emissiveColor);
        specularEditor.setValue(specularColor);
        shininessSlider.setValue(shininess);
    }
}
